@@ -21,7 +21,10 @@
 
 static GtkWidget *capplet=NULL;
 
+#if 0
 static GtkWidget *preview;
+#endif
+
 static GtkWidget *monitor;
 
 static GtkWidget *fileSel = NULL;
@@ -614,7 +617,6 @@ color_setup (struct bgState *state)
 {
     GtkWidget *frame;
     GtkWidget *table;
-    GtkWidget *button1;
     
     frame = gtk_frame_new (_("Color"));
     
@@ -797,8 +799,6 @@ set_monitor_filename (gchar *str)
 static void
 wp_selection_ok (GtkWidget *w, GtkWidget **f)
 {
-	GtkWidget *cf = *f;
-	
 	if (w) {
 	  if (wpFileSelName)
 		g_free (wpFileSelName);
@@ -1128,6 +1128,14 @@ background_help(GtkWidget *widget, struct bgState *state)
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
+  } else {
+    GtkWidget *mbox;
+
+    mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+				 GNOME_MESSAGE_BOX_ERROR,
+				 _("Close"), NULL);
+
+    gtk_widget_show(mbox);
   }
 }
 
@@ -1198,7 +1206,6 @@ background_write (struct bgState *state)
 void
 background_read ( struct bgState *state )
 {
-	GdkColor bgColor;
 	gint r, g, b;
 
 	gdk_color_parse
@@ -1315,7 +1322,7 @@ background_setup (struct bgState *state)
 
     GtkWidget *settings;
     GtkWidget *vbox, *hbox;
-    GtkWidget *align;
+    GtkWidget *align, *align2;
 
     capplet = capplet_widget_new();
 
@@ -1323,7 +1330,8 @@ background_setup (struct bgState *state)
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER(hbox), GNOME_PAD);
 
-    align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+    align  = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+    align2 = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 
     monitor = get_monitor_preview_widget ();
 
@@ -1345,9 +1353,10 @@ background_setup (struct bgState *state)
 		     MONITOR_CONTENTS_HEIGHT);
 #endif
     gtk_container_add (GTK_CONTAINER (align), monitor);
-    gtk_box_pack_start (GTK_BOX(hbox), align, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX(hbox), align, TRUE, TRUE, 0); 
+    gtk_container_add (GTK_CONTAINER (align2), hbox);
 
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), align2, TRUE, TRUE, 0);
 
     	
     radion = gtk_check_button_new_with_label ( _("Disable background selection") );
@@ -1356,7 +1365,7 @@ background_setup (struct bgState *state)
 
     settings = gtk_hbox_new (FALSE, GNOME_PAD);
     gtk_container_set_border_width (GTK_CONTAINER(settings), GNOME_PAD);
-    gtk_box_pack_end (GTK_BOX (vbox), settings, TRUE, TRUE, 0);
+    gtk_box_pack_end (GTK_BOX (vbox), settings, FALSE, FALSE, 0);
 
     fill = color_setup (state);
     gtk_box_pack_start (GTK_BOX (settings), fill, FALSE, FALSE, 0);
@@ -1375,6 +1384,7 @@ background_setup (struct bgState *state)
 			NULL);
 
     gtk_widget_show (align);
+    gtk_widget_show (align2);
     gtk_widget_show (monitor);
     gtk_widget_show (settings);
     gtk_widget_show (hbox);
