@@ -55,9 +55,17 @@ static void bell_help(void)
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
-  }
+  } else {
+          GtkWidget *mbox;
 
+          mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+                                       GNOME_MESSAGE_BOX_ERROR,
+                                       _("Close"), NULL);
+
+          gtk_widget_show(mbox);
+  }
 }
+
 static void bell_apply(void)
 {
 	kbdcontrol.bell_percent = bell_percent;
