@@ -643,8 +643,6 @@ dialog_callback (GtkWidget *dialog, gint button, screensaver_data *newsd)
         static GdkWindow *sswin = NULL;
         GdkWindowAttr attributes;
         gchar xid[11];
-        gchar **argv;
-
 
         store_screensaver_data (newsd);
         switch (button) {
@@ -671,16 +669,24 @@ dialog_callback (GtkWidget *dialog, gint button, screensaver_data *newsd)
                 if (pid_big == (pid_t) -1)
                         return;
                 if (pid_big == 0) {
+                        char *ctmp, *envpath;
+                        char **argv;
+                        
                         snprintf (xid, 11,"0x%x", (guint) GDK_WINDOW_XWINDOW (sswin));
-#ifdef HAVE_REDHAT_XSCREENSAVER_RPM                        
-                        temp = g_strconcat ("/usr/X11R6/lib/xscreensaver/", newsd->args, " ", newsd->windowid, " ", xid, NULL);
-#else
+
+                        envpath = getenv("PATH");
+                        ctmp = g_strdup_printf("%s%s%s",
+                                               envpath?envpath:"",
+                                               envpath?":":"",
+                                               "/usr/X11R6/lib/xscreensaver");
+                        setenv("PATH", ctmp, 1);
+                        
                         temp = g_strconcat (newsd->args, " ", newsd->windowid, " ", xid, NULL);
-#endif
                         argv = g_strsplit (temp, " ", -1);
 
+                        g_print ("argv: %s\n", temp);
                         execvp (argv[0], argv);
-                        exit (1);
+                        _exit (1);
                         /* This call should never return */
                 }
                 break;
@@ -790,8 +796,16 @@ help_callback (void)
 
   tmp = gnome_help_file_find_file ("users-guide", "gccdesktop.html#GCCSCREEN");
   if (tmp) {
-    gnome_help_goto(0, tmp);
-    g_free(tmp);
+          gnome_help_goto(0, tmp);
+          g_free(tmp);
+  } else {
+          GtkWidget *mbox;
+
+          mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+                                       GNOME_MESSAGE_BOX_ERROR,
+                                       _("Close"), NULL);
+
+          gtk_widget_show(mbox);
   }
 
 }
