@@ -226,7 +226,7 @@ gsm_session_destroy (GtkObject *o)
       command (the_protocol, 
 	       gsm_args_to_prop (GsmCommand, 
 				 GsmDeselectClientEvents, NULL), NULL);
-      live_session == NULL;
+      live_session = NULL;
     }
   else
     {
@@ -497,7 +497,7 @@ client_reasons (GsmClient* client, gboolean confirm, GSList* reasons)
   
   /* Hmm, may need to be override redirect as well since WMs are quite
      likely to be the source of the errors... */
-  //dialog = gnome_warning_dialog (message);
+  /* dialog = gnome_warning_dialog (message); */
   dialog = gnome_message_box_new (message, GNOME_MESSAGE_BOX_WARNING, NULL);
   gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (dialog),
 					  _("Remove Program"),
