@@ -177,11 +177,11 @@ static SoundProps *
 sound_properties_create(void)
 {
     GtkWidget *table, *vbox, *wtmp, *notebook;
+    GtkWidget *hbox, *volume;
     GtkWidget *frame;
     char *path;
     char *filename;
     static const char *ctree_column_titles[] = {
-        N_("Category"),
         N_("Event"),
         N_("File to Play")
     };
@@ -290,8 +290,7 @@ sound_properties_create(void)
     
     ctree_column_titles[0] = _(ctree_column_titles[0]);
     ctree_column_titles[1] = _(ctree_column_titles[1]);
-    ctree_column_titles[2] = _(ctree_column_titles[2]);
-    retval->ctree = gtk_ctree_new_with_titles(3, 0,
+    retval->ctree = gtk_ctree_new_with_titles(2, 0,
                                               (gchar **)ctree_column_titles);
 
     gtk_clist_set_selection_mode(GTK_CLIST(retval->ctree), GTK_SELECTION_BROWSE);
@@ -302,9 +301,8 @@ sound_properties_create(void)
 
     sound_properties_regenerate_ctree(retval);
 
-/*    gtk_clist_set_column_auto_resize(GTK_CLIST(retval->ctree), 0, TRUE); */
-    gtk_clist_set_column_auto_resize(GTK_CLIST(retval->ctree), 1, TRUE);
-    gtk_clist_set_column_auto_resize(GTK_CLIST(retval->ctree), 2, TRUE);
+    gtk_clist_set_column_auto_resize(GTK_CLIST(retval->ctree), 0, TRUE);
+    /*    gtk_clist_set_column_auto_resize(GTK_CLIST(retval->ctree), 1, TRUE);*/
 
     gtk_container_set_border_width(GTK_CONTAINER(table), GNOME_PAD_SMALL);
     wtmp = gtk_scrolled_window_new(NULL, NULL);
@@ -316,8 +314,16 @@ sound_properties_create(void)
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(wtmp), GTK_POLICY_AUTOMATIC,
                                    GTK_POLICY_ALWAYS);
     gtk_table_attach_defaults(GTK_TABLE(table), wtmp, 0, 2, 0, 1);
+
+    retval->btn_play = gtk_button_new ();
+    hbox = gtk_hbox_new (FALSE, 0);
+    volume = gnome_stock_pixmap_widget (retval->btn_play, GNOME_STOCK_PIXMAP_VOLUME);
+    gtk_box_pack_start (GTK_BOX (hbox), volume, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("Play")), FALSE, FALSE, 8);
+    gtk_container_add (GTK_CONTAINER (retval->btn_play), hbox);
+
     gtk_table_attach(GTK_TABLE(table),
-                     (retval->btn_play = gtk_button_new_with_label(_("Play"))),
+                     retval->btn_play, 
                      0, 1, 1, 2,
                      GTK_EXPAND|GTK_SHRINK, 0,
                      GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -414,7 +420,7 @@ sound_properties_read_path(SoundProps *props,
     gpointer event_iter;
     GtkCTreeNode *category_node = NULL, *event_node = NULL,
         *prev_event_node = NULL;
-    char *arow[4] = {NULL,NULL,NULL,NULL};
+    char *arow[2] = {NULL,NULL};
     struct dirent *dent;
     GHashTable *cathash;
 
@@ -435,7 +441,7 @@ sound_properties_read_path(SoundProps *props,
 
         gnome_config_push_prefix(tmpstr->str);
 
-        arow[1] = ""; arow[2] = "";
+        arow[1] = ""; 
 
         ctmp = gnome_config_get_translated_string("__section_info__/description");
         if(ctmp && *ctmp) {
@@ -484,7 +490,7 @@ sound_properties_read_path(SoundProps *props,
             }
 
             g_string_sprintf(tmpstr, "%s/file", sample_name);
-            arow[2] = sample_file = gnome_config_get_string(tmpstr->str);
+            arow[1] = sample_file = gnome_config_get_string(tmpstr->str);
 
             event_node = g_hash_table_lookup(cathash, sample_name);
 
@@ -496,19 +502,18 @@ sound_properties_read_path(SoundProps *props,
                 g_free(new_entry->file);
 
                 gtk_ctree_node_set_text(GTK_CTREE(props->ctree), event_node,
-                                        2, sample_file);
+                                        1, sample_file);
 
                 new_entry->file = sample_file;
                 g_free(sample_name);
 
             } else {
 
-                arow[0] = "";
                 g_string_sprintf(tmpstr, "%s/description", sample_name);
-                arow[1] = gnome_config_get_translated_string(tmpstr->str);
-                if(!arow[1] || !*arow[1]) {
-                    g_free(arow[1]);
-                    arow[1] = g_strdup(sample_name);
+                arow[0] = gnome_config_get_translated_string(tmpstr->str);
+                if(!arow[1] || !*arow[0]) {
+                    g_free(arow[0]);
+                    arow[0] = g_strdup(sample_name);
                 }
 
                 event_node = gtk_ctree_insert_node(GTK_CTREE(props->ctree),
@@ -516,7 +521,7 @@ sound_properties_read_path(SoundProps *props,
                                                    arow, GNOME_PAD_SMALL,
                                                    NULL, NULL, NULL, NULL, TRUE,
                                                    FALSE);
-                g_free(arow[1]);
+                g_free(arow[0]);
                 new_entry = g_new0(SoundEvent, 1);
                 new_entry->category = g_strdup(file);
                 new_entry->name = sample_name;
@@ -563,7 +568,7 @@ sound_properties_event_change_file(GtkEditable *entry, SoundProps *props)
 
     gtk_ctree_node_set_text(GTK_CTREE(props->ctree),
                             GTK_CLIST(props->ctree)->selection->data,
-                            2, tmp2);
+                            1, tmp2);
 }
 
 static void
@@ -574,7 +579,7 @@ sound_properties_event_select(GtkCTree *ctree,
 {
     char *ctmp;
 
-    ctmp = GTK_CLIST_ROW(&row->list)->cell[2].u.text;
+    ctmp = GTK_CLIST_ROW(&row->list)->cell[1].u.text;
     if(!ctmp)
         ctmp = "";
 
@@ -599,7 +604,7 @@ sound_properties_event_apply(GtkCTree *ctree,
     g_return_if_fail(ev);
 
     gtk_ctree_node_get_text(GTK_CTREE(ctree),
-                            node, 2, &cur_filename);
+                            node, 1, &cur_filename);
 
     if(!cur_filename || !(*cur_filename)) return;
 
@@ -679,6 +684,14 @@ ui_do_help(void)
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
+  } else {
+      GtkWidget *mbox;
+
+      mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+                                   GNOME_MESSAGE_BOX_ERROR,
+                                   _("Close"), NULL);
+
+      gtk_widget_show(mbox);
   }
 }
 
@@ -716,7 +729,7 @@ sound_properties_play_sound(GtkWidget *btn, SoundProps *props)
     g_return_if_fail(GTK_CLIST(props->ctree)->selection);
 
     node = GTK_CTREE_NODE(GTK_CLIST(props->ctree)->selection->data);
-    ctmp = GTK_CLIST_ROW(&node->list)->cell[2].u.text;
+    ctmp = GTK_CLIST_ROW(&node->list)->cell[1].u.text;
 
     if(*ctmp == '/' || g_file_exists(ctmp))
         ctmp2 = g_strdup(ctmp);
