@@ -485,6 +485,39 @@ revert (GtkWidget *capplet, gpointer data)
 	}
 }
 
+static void
+help (GtkWidget *capplet)
+{
+  gchar *tmp, *helpfile;
+
+  switch(CAPPLET_WIDGET(capplet)->capid) {
+  case 0: /* Dialogs */
+  default:
+    helpfile = "gccui.html#GCCDIALOGS";
+    break;
+  case 1: /* Application */
+    helpfile = "gccui.html#GCCAPPDEFAULTS";
+    break;
+  case 2: /* MDI */
+    helpfile = "gccui.html#GCCMDI";
+    break;
+  }
+
+  tmp = gnome_help_file_find_file ("users-guide", helpfile);
+  if (tmp) {
+    gnome_help_goto(0, tmp);
+    g_free(tmp);
+  } else {
+    GtkWidget *mbox;
+
+    mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+				 GNOME_MESSAGE_BOX_ERROR,
+				 _("Close"), NULL);
+
+    gtk_widget_show(mbox);
+  }
+}
+
 static void
 ui_setup (GtkWidget *old, GtkWidget *the_capplet)
 {
@@ -520,6 +553,8 @@ ui_setup (GtkWidget *old, GtkWidget *the_capplet)
 			    GTK_SIGNAL_FUNC (try), NULL);
 	gtk_signal_connect (GTK_OBJECT (the_capplet), "cancel",
 			    GTK_SIGNAL_FUNC (revert), NULL);
+	gtk_signal_connect (GTK_OBJECT (the_capplet), "help",
+			    GTK_SIGNAL_FUNC (help), NULL);
 }
 
 int
