@@ -66,7 +66,16 @@ help_callback (GtkWidget *widget, gpointer data)
         if (tmp) {
                 gnome_help_goto(0, tmp);
                 g_free(tmp);
+        } else {
+                GtkWidget *mbox;
+
+                mbox = gnome_message_box_new(_("No help is available/installed. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+                                             GNOME_MESSAGE_BOX_ERROR,
+                                             _("Close"), NULL);
+
+                gtk_widget_show(mbox);
         }
+
 }
 static void
 delete_callback (GtkWidget *widget, gpointer data)
