@@ -35,12 +35,12 @@ struct _timer_entry
         guint timer_id;
 };
 /* prototypes */
-void try_button_callback(GtkWidget *widget, gpointer data);
-void revert_button_callback(GtkWidget *widget, gpointer data);
-void ok_button_callback(GtkWidget *widget, gpointer data);
-void cancel_button_callback(GtkWidget *widget, gpointer data);
-void help_button_callback(GtkWidget *widget, gpointer data);
-void close_capplet (gboolean show_splash, gpointer data);
+static void try_button_callback(GtkWidget *widget, gpointer data);
+static void revert_button_callback(GtkWidget *widget, gpointer data);
+static void ok_button_callback(GtkWidget *widget, gpointer data);
+static void cancel_button_callback(GtkWidget *widget, gpointer data);
+static void help_button_callback(GtkWidget *widget, gpointer data);
+static void close_capplet (gboolean show_splash, gpointer data);
 static void exec_capplet (node_data *data);
 static void shutdown_capplet (node_data *nd);
 static void capplet_close_callback (GtkWidget *widget, gpointer data);
@@ -223,9 +223,22 @@ launch_capplet (node_data *data, gboolean exec_new)
                 gtk_ctree_select (data->ctree, data->node);
         }
 }
+void
+revert_all ()
+{
+        GList *list;
+        node_data *nd;
+
+        for (list = capplet_list; list; list = list->next) {
+                nd = (node_data *) list->data;
+                if (nd && nd->capplet)
+                        GNOME_capplet_cancel (nd->capplet,nd->id, &ev);
+        }
+}
 
 
-void try_button_callback(GtkWidget *widget, gpointer data)
+static void
+try_button_callback(GtkWidget *widget, gpointer data)
 {
         node_data *nd = (node_data *) data;
         if  (!nd->capplet)
@@ -233,7 +246,8 @@ void try_button_callback(GtkWidget *widget, gpointer data)
         gtk_widget_set_sensitive (nd->try_button, FALSE);
         GNOME_capplet_try (nd->capplet,nd->id, &ev);
 }
-void revert_button_callback(GtkWidget *widget, gpointer data)
+static void
+revert_button_callback(GtkWidget *widget, gpointer data)
 {
         node_data *nd = (node_data *) data;
         if (!nd->capplet)
@@ -242,7 +256,8 @@ void revert_button_callback(GtkWidget *widget, gpointer data)
         gtk_widget_set_sensitive (nd->try_button, FALSE);
         gtk_widget_set_sensitive (nd->revert_button, FALSE);
 }
-void ok_button_callback(GtkWidget *widget, gpointer data)
+static void
+ok_button_callback(GtkWidget *widget, gpointer data)
 {
         GtkStyle *style;
         node_data *nd = (node_data *) data;
@@ -253,7 +268,8 @@ void ok_button_callback(GtkWidget *widget, gpointer data)
         close_capplet (TRUE, data);
         gtk_ctree_node_set_foreground (nd->ctree, nd->node, &style->fg[GTK_STATE_NORMAL]);
 }
-void cancel_button_callback(GtkWidget *widget, gpointer data)
+static void
+cancel_button_callback(GtkWidget *widget, gpointer data)
 {
         GtkStyle *style;
         node_data *nd = (node_data *) data;
@@ -355,7 +371,7 @@ shutdown_capplet (node_data *nd) {
 /* If show_splash is true, then that means that we want to handle whatever is underneath
  * (ie. putting the splashscreen back, changing the selected node etc. )
  * Otherwise we ignore what's underneath (ie. we're about to launch another one.) */
-void
+static void
 close_capplet (gboolean show_splash, gpointer data)
 {
         node_data *nd = (node_data *) data;
@@ -392,7 +408,9 @@ close_capplet (gboolean show_splash, gpointer data)
                         }
         }
 }
-void help_button_callback(GtkWidget *widget, gpointer data)
+
+static void
+help_button_callback(GtkWidget *widget, gpointer data)
 {
         node_data *nd = (node_data *) data;
         GNOME_capplet_help (nd->capplet,nd->id, &ev);
