@@ -9,6 +9,7 @@
 #include "callbacks.h"
 #include "tree.h"
 #include "corba-glue.h"
+#include "capplet-manager.h"
 GtkWidget *main_window;
 GtkWidget *exit_dialog;
 GtkWidget *hpane;
@@ -93,10 +94,11 @@ create_exit_dialog (GList *apps)
                 gtk_clist_append (GTK_CLIST (list), text);
                 gtk_clist_set_row_data (GTK_CLIST (list), i++, apps->data);
         }
-        gtk_signal_connect( GTK_OBJECT (list),"select_row", GTK_SIGNAL_FUNC (exit_row_callback), NULL);
+        gtk_signal_connect (GTK_OBJECT (list),"select_row", GTK_SIGNAL_FUNC (exit_row_callback), NULL);
         gnome_dialog_button_connect (GNOME_DIALOG (retval), 0, exit_dialog_ok_callback, NULL);
         gnome_dialog_button_connect (GNOME_DIALOG (retval), 1, exit_dialog_cancel_callback, NULL);
-
+        gtk_signal_connect (GTK_OBJECT (retval), "destroy", exit_dialog_close_callback, NULL);
+        
         /* and put it all together */
         gtk_box_pack_start (GTK_BOX (right_vbox), label, FALSE, FALSE, 5);
         gtk_box_pack_start (GTK_BOX (right_vbox), list, FALSE, FALSE, 5);
@@ -115,7 +117,8 @@ create_exit_dialog (GList *apps)
         
         return retval;
 }
-void
+
+static void
 gtk_widget_set_uposition_internal (GtkWidget *widget,
                                    gint	     x,
                                    gint	     y)
@@ -149,9 +152,31 @@ gtk_widget_set_uposition_internal (GtkWidget *widget,
   if (GTK_WIDGET_VISIBLE (widget) && widget->parent)
     gtk_widget_size_allocate (widget, &widget->allocation);
 }
-GtkWidget *
+
+#if 0
+/*
+ * This is a helper function used to find the "System Information"
+ * capplet in the capplet tree.
+ */
+static gint
+find_guname_helper (gconstpointer a, gconstpointer b)
+{
+        node_data *nd = (node_data *) a;
+
+        if (nd == NULL || nd->gde == NULL || nd->gde->exec == NULL)
+                return 1;
+
+        if (strstr (nd->gde->exec[0], "guname") != NULL)
+                return 0;
+
+        return 1;
+}
+#endif
+
+static GtkWidget *
 create_window ()
 {
+/*        GtkCTreeNode *guname_node;*/
         GtkWidget *retval;
         GdkPixmap *temp_splash;
         GtkWidget *vbox;
@@ -211,6 +236,22 @@ create_window ()
         gtk_widget_set_usize (window, 100, 100);
         gtk_widget_set_uposition_internal (window, -300, -300);
         gtk_widget_show_all (window);
+
+#if 0
+        /*
+         * If there is an entry for guname in the tree, launch it as
+         * the default capplet.
+         */
+        /* I don't like this.  Plus, it has a race condition.  Commented out for now - jrb */
+        guname_node = gtk_ctree_find_by_row_data_custom (GTK_CTREE (tree), NULL, NULL, find_guname_helper);
+        if (guname_node != NULL) {
+                node_data *guname_nd;
+
+                guname_nd = gtk_ctree_node_get_row_data (GTK_CTREE (tree), guname_node);
+                launch_capplet (guname_nd, TRUE);
+        }
+#endif
+
         return retval;
 }
 
