@@ -282,7 +282,7 @@ generate_tree ()
         gtk_ctree_set_indent (GTK_CTREE (retval), 15);
         gtk_clist_set_column_auto_resize (GTK_CLIST (retval), 0, TRUE);
         /*gtk_widget_set_usize (retval, 200, 375);*/
-        gtk_clist_set_selection_mode(GTK_CLIST(retval), GTK_SELECTION_BROWSE);
+        gtk_clist_set_selection_mode(GTK_CLIST(retval), GTK_SELECTION_SINGLE);
         gtk_signal_connect( GTK_OBJECT (retval),"tree_select_row", GTK_SIGNAL_FUNC (selected_row_callback), NULL);
 
         /* load the directories */
